@@ -264,10 +264,10 @@ App::~App()
     //mainWindow()->deleteBrowsers();
     delete mainWindow();
 
-    CollectionManager::destroy();
     Playlist::ModelStack::destroy();
     Playlist::Actions::destroy();
     PlaylistManager::destroy();
+    CollectionManager::destroy();
     CoverFetcher::destroy();
     NetworkAccessManagerProxy::destroy();
 
@@ -657,12 +657,6 @@ App::continueInit()
     QDBusConnection::sessionBus().registerService("org.mpris.amarok");
     PERF_LOG( "Done creating DBus handlers" )
 
-    if( splash ) // close splash correctly
-    {
-        splash->close();
-        delete splash;
-    }
-
     //DON'T DELETE THIS NEXT LINE or the app crashes when you click the X (unless we reimplement closeEvent)
     //Reason: in ~App we have to call the deleteBrowsers method or else we run afoul of refcount foobar in KHTMLPart
     //But if you click the X (not Action->Quit) it automatically kills MainWindow because KMainWindow sets this
@@ -697,6 +691,12 @@ App::continueInit()
     // Restore keyboard shortcuts etc from config
     Amarok::actionCollection()->readSettings();
 
+    if( splash ) // close splash correctly
+    {
+        splash->close();
+        delete splash;
+    }
+
     PERF_LOG( "App init done" )
     KConfigGroup config = KGlobal::config()->group( "General" );
 
@@ -787,8 +787,21 @@ App::continueInit()
         aUrl.run();
     }
     s_delayedAmarokUrls.clear();
+
+    QTimer::singleShot( 1500, this, SLOT( resizeMainWindow() ) );
 }
 
+
+void App::resizeMainWindow() // SLOT
+{
+    // HACK
+    // This code works around a bug in KDE 4.5, which causes our Plasma applets to show
+    // with a wrong initial size. Remove when this bug is fixed in Plasma.
+    m_mainWindow->resize( m_mainWindow->width(), m_mainWindow->height() - 1 );
+    m_mainWindow->resize( m_mainWindow->width(), m_mainWindow->height() + 1 );
+}
+
+
 void App::checkCollectionScannerVersion()  // SLOT
 {
     DEBUG_BLOCK
