@@ -19,6 +19,8 @@
 #include "AmarokUrlHandler.h"
 #include "context/ContextView.h"
 
+#include <KLocale>
+
 ContextUrlRunner::ContextUrlRunner()
 {}
 
@@ -51,7 +53,7 @@ bool ContextUrlRunner::run( AmarokUrl url )
     Context::Containment* cont = dynamic_cast< Context::Containment* >( Context::ContextView::self()->containment() );
     if( cont )
     {
-        foreach( QString appletPluginName, appletList )
+        foreach( const QString &appletPluginName, appletList )
         {
             cont->addApplet( appletPluginName, -1 );
         }
@@ -65,3 +67,8 @@ QString ContextUrlRunner::command() const
     return "context";
 }
 
+QString ContextUrlRunner::prettyCommand() const
+{
+    return i18nc( "A type of command that affects the context view", "Context" );
+}
+
