@@ -43,7 +43,7 @@ class CollectionTreeItemModelBase;
 class CollectionTreeItem : public QObject
 {
     Q_OBJECT
-    Q_ENUMS( Type );
+    Q_ENUMS( Type )
 
     public:
         enum Type
