@@ -138,7 +138,9 @@ PlaylistBrowserNS::DynamicModel::setActivePlaylist( int index )
     {
         return m_activePlaylistPtr;
     }
-    
+
+    m_activeUnsaved = false; // for now it seems that setting a new playlist always sets an unmodified one
+
     // delete old one
     m_activePlaylistPtr.clear();
 
@@ -385,6 +387,7 @@ PlaylistBrowserNS::DynamicModel::saveActive( const QString& newTitle )
 {
     DEBUG_BLOCK
 
+    qDebug() << "PlaylistBrowser::..::saveActive" << newTitle << "unsaved" << m_activeUnsaved << "contains" << m_playlistHash.contains( newTitle );
     // user has made modifications
     if( m_activeUnsaved )
     {
@@ -393,7 +396,7 @@ PlaylistBrowserNS::DynamicModel::saveActive( const QString& newTitle )
         // replace or add new playlist
         if( m_playlistHash.contains( newTitle ) )
         {
-            m_savedPlaylistsRoot.replaceChild( m_playlistHash[ newTitle ],e );
+            m_savedPlaylistsRoot.replaceChild( e, m_playlistHash[ newTitle ] );
             m_playlistHash[ newTitle ] = e;
 
             m_playlistElements[ m_activePlaylist ] = e;
