@@ -15,6 +15,8 @@
  * this program.  If not, see <http://www.gnu.org/licenses/>.                           *
  ****************************************************************************************/
 
+#define DEBUG_PREFIX "PlaylistBrowserView"
+
 #include "PlaylistBrowserView.h"
 
 #include "core/support/Debug.h"
@@ -87,13 +89,18 @@ PlaylistBrowserNS::PlaylistBrowserView::mousePressEvent( QMouseEvent *event )
         return;
     }
 
-    const int actionCount =
-            index.data( PlaylistBrowserNS::PlaylistBrowserModel::ActionCountRole ).toInt();
-    if( actionCount > 0 )
+    // HACK: provider elements hide the root decorations
+    // Don't bother checking actions for the others.
+    if( !rootIsDecorated() && !index.parent().isValid() )
     {
-        const QRect rect = PlaylistTreeItemDelegate::actionsRect( index );
-        if( rect.contains( event->pos() ) )
-            return;
+        const int actionCount =
+            index.data( PlaylistBrowserNS::PlaylistBrowserModel::ActionCountRole ).toInt();
+        if( actionCount > 0 )
+        {
+            const QRect rect = PlaylistTreeItemDelegate::actionsRect( index );
+            if( rect.contains( event->pos() ) )
+                return;
+        }
     }
 
     bool prevExpandState = isExpanded( index );
@@ -110,7 +117,9 @@ void
 PlaylistBrowserNS::PlaylistBrowserView::mouseReleaseEvent( QMouseEvent * event )
 {
     const QModelIndex index = indexAt( event->pos() );
-    if( !index.parent().isValid() ) // not a root element, don't bother checking actions
+    // HACK: provider elements hide the root decorations
+    // Don't bother checking actions for the others.
+    if( !rootIsDecorated() && !index.parent().isValid() )
     {
         const int actionCount =
             index.data( PlaylistBrowserNS::PlaylistBrowserModel::ActionCountRole ).toInt();
@@ -262,7 +271,7 @@ PlaylistBrowserNS::PlaylistBrowserView::keyPressEvent( QKeyEvent *event )
 
 void PlaylistBrowserNS::PlaylistBrowserView::contextMenuEvent( QContextMenuEvent * event )
 {
-    QModelIndexList indices = selectionModel()->selectedIndexes();
+    QModelIndexList indices = selectedIndexes();
 
     QList<QAction *> actions = actionsFor( indices );
 
@@ -311,4 +320,12 @@ PlaylistBrowserNS::PlaylistBrowserView::setNewFolderAction( KAction *action )
     m_addFolderAction = action;
 }
 
+void
+PlaylistBrowserNS::PlaylistBrowserView::currentChanged( const QModelIndex &current,
+                                                        const QModelIndex &previous )
+{
+    Q_UNUSED( previous )
+    emit currentItemChanged( current );
+}
+
 #include "PlaylistBrowserView.moc"
