@@ -25,6 +25,8 @@
 class AlbumsModel : public QStandardItemModel
 {
      public:
+         AlbumsModel( QObject *parent = 0 );
+         virtual ~AlbumsModel() {}
          virtual QMimeData* mimeData(const QModelIndexList & indices) const;
          virtual QMimeData* mimeData(const QList<QStandardItem*> & items) const;
          virtual QStringList mimeTypes() const;
