@@ -50,6 +50,9 @@
 LabelsApplet::LabelsApplet( QObject *parent, const QVariantList &args )
     : Context::Applet( parent, args )
     , Engine::EngineObserver( The::engineController() )
+    , m_titleLabel( 0 )
+    , m_addLabel( 0 )
+    , m_addLabelProxy( 0 )
     , m_reloadIcon( 0 )
     , m_settingsIcon( 0 )
 {
@@ -59,7 +62,6 @@ LabelsApplet::LabelsApplet( QObject *parent, const QVariantList &args )
 LabelsApplet::~LabelsApplet()
 {
     qDeleteAll( m_labelItems );
-    delete m_titleLabel;
     delete m_addLabelProxy;
 
     delete m_reloadIcon;
@@ -182,6 +184,9 @@ LabelsApplet::resultReady( const QString &collectionId, const Meta::LabelList &l
 void
 LabelsApplet::engineNewTrackPlaying( )
 {
+    if( !m_addLabelProxy )
+        return;
+
     DEBUG_BLOCK
     m_currentLabels.clear();
     m_labelInfos.clear();
@@ -224,6 +229,10 @@ LabelsApplet::enginePlaybackEnded( qint64 finalPosition, qint64 trackLength, Pla
     Q_UNUSED( finalPosition )
     Q_UNUSED( trackLength )
     DEBUG_BLOCK
+
+    if( !m_addLabelProxy )
+        return;
+
     m_currentLabels.clear();
     m_labelInfos.clear();
     updateLabels();
@@ -299,6 +308,10 @@ LabelsApplet::updateLabels()
     while( it_final.hasNext() )
     {
         it_final.next();
+        
+        if( it_final.key().isEmpty() ) // empty labels don't make sense but they cause a freeze
+            continue;
+
         int i_size = (int)( it_final.value() / 10 - 5 );
         if( i_size < -1 )
             i_size = -1;
@@ -387,8 +400,9 @@ LabelsApplet::constraintsEvent( Plasma::Constraints constraints )
         y_pos += m_addLabelProxy->size().height() + standardPadding();
 
         resize( size().width(), y_pos );
-        setMinimumSize( size().width(), y_pos );
-        setMaximumSize( size().width(), y_pos );
+        setMinimumHeight( y_pos );
+        setMaximumHeight( y_pos );
+        emit sizeHintChanged( Qt::PreferredSize );
     }
 }
 
@@ -466,10 +480,13 @@ void
 LabelsApplet::addLabelPressed()
 {
     QString label = m_addLabel->currentText();
+
+    if( label.isEmpty() )
+        return;
+
     if( !m_currentLabels.contains( label ) )
     {
         toggleLabel( label );
-        m_addLabel->clearEditText();
         if( !m_allLabels.contains( label ) )
         {
             m_allLabels.append( label );
@@ -478,6 +495,7 @@ LabelsApplet::addLabelPressed()
             m_addLabel->insertItems( 0, m_allLabels );
             m_addLabel->completionObject()->setItems( m_allLabels );
         }
+        m_addLabel->clearEditText();
     }
 }
 
@@ -486,6 +504,9 @@ LabelsApplet::toggleLabel( const QString &label )
 {
     DEBUG_BLOCK
     bool selected;
+
+    if( label.isEmpty() )
+        return;
     
     Meta::TrackPtr track = The::engineController()->currentTrack();
 
