@@ -20,11 +20,9 @@
 #include "ContextObserver.h"
 #include "context/DataEngine.h"
 #include "core/meta/Meta.h"
+#include "NetworkAccessManagerProxy.h"
 #include "PhotosInfo.h"
 
-// forward
-class KJob;
-
 using namespace Context;
 
  /**
@@ -58,15 +56,15 @@ private slots:
    *   http://api.flickr.com/services/rest/?method=flickr.photos.search&api_key=9c5a288116c34c17ecee37877397fe31&text=My+Bloody+Valentine
    *   see here for details: http://www.flickr.com/services/api/
    */
-    void resultFlickr( KJob* );
+    void resultFlickr( const KUrl &url, QByteArray data, NetworkAccessManagerProxy::Error e );
 
   /**
    *   An image fetcher, will store the QPixmap in the corresponding videoInfo
    */
-    void resultImageFetcher( KJob * );
+    void resultImageFetcher( const KUrl &url, QByteArray data, NetworkAccessManagerProxy::Error e );
 
   /**
-   *   This method will send the info to the applet and order them if every jobs are finished
+   *   This method will send the info to the applet and order them if every job are finished
    */
     void resultFinalize();
 
@@ -81,13 +79,11 @@ private:
     // TODO implement a reload
     void reloadPhotos();
 
-
-    KJob* m_jobFlickr;
-
     int m_nbFlickr;
     int m_nbPhotos;
 
-    QList < QString > m_listJob;
+    QSet<KUrl> m_flickrUrls;
+    QSet<KUrl> m_imageUrls;
 
     QStringList m_sources;
 
