@@ -8,14 +8,14 @@
  *                                                                                      *
  * This program is distributed in the hope that it will be useful, but WITHOUT ANY      *
  * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A      *
- * PARTICULAR PURPOSE. See the GNU General Public License for more details.              *
+ * PARTICULAR PURPOSE. See the GNU General Public License for more details.             *
  *                                                                                      *
  * You should have received a copy of the GNU General Public License along with         *
  * this program.  If not, see <http://www.gnu.org/licenses/>.                           *
  ****************************************************************************************/
 
-#ifndef _JSONQT_JSON_TO_VARIANT_H
-#define _JSONQT_JSON_TO_VARIANT_H
+#ifndef JSONQT_JSON_TO_VARIANT_H
+#define JSONQT_JSON_TO_VARIANT_H
 
 #include "ParseException.h"
 
