@@ -25,7 +25,7 @@
 #include "AppletExplorer.h"
 
 #include "AppletIcon.h"
-#include "Debug.h"
+#include "core/support/Debug.h"
 #include "PaletteHandler.h"
 
 #include <plasma/containment.h>
@@ -38,7 +38,7 @@
 #include <QStyleOptionGraphicsItem>
 #include <QSizePolicy>
 
-#define HEIGHT 120
+#define HEIGHT 130
 #define ICON_SIZE 16
 
 
