@@ -24,7 +24,7 @@
  ****************************************************************************************/
 
 #include "AppletsList.h"
-#include "Debug.h"
+#include "core/support/Debug.h"
 
 #include <KIcon>
 
