@@ -94,7 +94,6 @@ class EditCapabilityImpl : public Capabilities::EditCapability
         virtual void setDiscNumber( int newDiscNumber ) { m_track->setDiscNumber( newDiscNumber ); }
         virtual void beginMetaDataUpdate() { m_track->beginMetaDataUpdate(); }
         virtual void endMetaDataUpdate() { m_track->endMetaDataUpdate(); }
-        virtual void abortMetaDataUpdate() { m_track->abortMetaDataUpdate(); }
 
     private:
         KSharedPtr<Meta::SqlTrack> m_track;
@@ -137,11 +136,6 @@ class StatisticsCapabilityImpl : public Capabilities::StatisticsCapability
             m_track->endMetaDataUpdate();
             m_track->setWriteAllStatisticsFields( false );
         }
-        virtual void abortStatisticsUpdate()
-        {
-            m_track->abortMetaDataUpdate();
-            m_track->setWriteAllStatisticsFields( false );
-        }
 
     private:
         KSharedPtr<Meta::SqlTrack> m_track;
