@@ -22,16 +22,16 @@
 
 #include "ScanManager.h"
 
+#include "amarokconfig.h"
 #include "App.h"
-#include "core/support/Debug.h"
+#include "playlistmanager/PlaylistManager.h"
 #include "ScanResultProcessor.h"
 #include "SqlCollection.h"
 #include "SqlCollectionDBusHandler.h"
-#include "amarokconfig.h"
+#include "statusbar/StatusBar.h"
+#include "core/support/Debug.h"
 #include "core/meta/support/MetaConstants.h"
 #include "core/meta/support/MetaUtility.h"
-#include "playlistmanager/PlaylistManager.h"
-#include "statusbar/StatusBar.h"
 
 #include <QFileInfo>
 #include <QListIterator>
@@ -104,7 +104,6 @@ ScanManager::startFullScan()
     }
 
     checkTables( true );
-    cleanTables();
 
     if( m_parser )
     {
@@ -437,6 +436,10 @@ ScanManager::getDirsToScan()
 
     QStringList result;
     QStringList collectionFolders = m_collection->mountPointManager()->collectionFolders();
+    //The below loop is not the most efficient loop ever but changing to something like a QSet introduces
+    //issues because of the differing ending / values. Changing those would require extreme care so as not
+    //to allow "Album" to satisfy the startsWith condition for "Album1", hence verifying against the full 
+    //path including trailing slash
     for( QListIterator<QString> iter( values ); iter.hasNext(); )
     {
         int id = iter.next().toInt();
@@ -576,20 +579,6 @@ ScanManager::restartScanner()
     m_scanner->start();
 }
 
-void
-ScanManager::cleanTables()
-{
-    DEBUG_BLOCK
-    m_storage->query( "DELETE FROM tracks;" );
-    m_storage->query( "DELETE FROM genres;" );
-    m_storage->query( "DELETE FROM years;" );
-    m_storage->query( "DELETE FROM composers;" );
-    m_storage->query( "DELETE FROM albums;" );
-    m_storage->query( "DELETE FROM artists;" );
-    m_storage->query( "DELETE FROM directories;" );
-    //images table is deleted in DatabaseUpdater::copyToPermanentTables
-}
-
 void
 ScanManager::checkTables( bool full )
 {
