@@ -25,6 +25,9 @@
 
 #include <QDir>
 #include <QImage>
+#if QT_VERSION >= 0x040600
+#include <QPixmapCache>
+#endif
 
 #include <KStandardDirs>
 
@@ -459,6 +462,12 @@ Meta::Album::image( int size )
     const QString &noCoverKey = QString::number( size ) + "@nocover.png";
 
     QPixmap pixmap;
+    // look in the memory pixmap cache
+#if QT_VERSION >= 0x040600
+    if( QPixmapCache::find( noCoverKey, &pixmap ) )
+        return pixmap;
+#endif
+
     if( cacheCoverDir.exists( noCoverKey ) )
     {
         pixmap.load( cacheCoverDir.filePath( noCoverKey ) );
@@ -469,6 +478,9 @@ Meta::Album::image( int size )
         pixmap = orgPixmap.scaled( size, size, Qt::KeepAspectRatio, Qt::SmoothTransformation );
         pixmap.save( cacheCoverDir.filePath( noCoverKey ), "PNG" );
     }
+#if QT_VERSION >= 0x040600
+    QPixmapCache::insert( noCoverKey, pixmap );
+#endif
     return pixmap;
 }
 
