@@ -21,13 +21,13 @@
 #include "core/capabilities/SourceInfoCapability.h"
 #include "core/playlists/PlaylistFormat.h"
 
-
 #include <QDateTime>
 #include <QTextDocument>
 
 #include <KCalendarSystem>
 #include <KConfigGroup>
 #include <KDirLister>
+#include <KGlobalSettings>
 #include <KStandardDirs>
 #include <KUniqueApplication>
 
@@ -204,6 +204,12 @@ namespace Amarok
         QApplication::restoreOverrideCursor();
     }
 
+    Qt::MouseButton contextMouseButton()
+    {
+        const int handed = KGlobalSettings::mouseSettings().handed;
+        return ( handed == KGlobalSettings::KMouseSettings::RightHanded ) ? Qt::RightButton : Qt::LeftButton;
+    }
+
     QString saveLocation( const QString &directory )
     {
         globalDirsMutex.lock();
@@ -354,7 +360,7 @@ namespace Amarok
     {
         typedef QMap<QString, KUrl> FileMap;
 
-        KDirLister lister ( false );
+        KDirLister lister( 0 );
         lister.setAutoUpdate ( false );
         lister.setAutoErrorHandlingEnabled ( false, 0 );
         lister.openUrl ( url );
