@@ -18,9 +18,9 @@
 
 #include "core/support/Amarok.h"
 
-#include <QDomNodeList>
 #include <QRegExp>
 #include <QSet>
+#include <QXmlStreamReader>
 
 #define DEBUG_PREFIX "CoverFetchUnit"
 #include "core/support/Debug.h"
@@ -41,7 +41,7 @@ CoverFetchUnit::CoverFetchUnit( Meta::AlbumPtr album,
 
 CoverFetchUnit::CoverFetchUnit( const CoverFetchPayload *payload, CoverFetch::Option opt )
     : QSharedData()
-    , m_album( Meta::AlbumPtr( 0 ) )
+    , m_album( payload->album() )
     , m_options( opt )
     , m_payload( payload )
 {
@@ -49,46 +49,12 @@ CoverFetchUnit::CoverFetchUnit( const CoverFetchPayload *payload, CoverFetch::Op
 
 CoverFetchUnit::CoverFetchUnit( const CoverFetchSearchPayload *payload )
     : QSharedData()
+    , m_album( payload->album() )
     , m_options( CoverFetch::WildInteractive )
     , m_payload( payload )
 {
 }
 
-CoverFetchUnit::CoverFetchUnit( const CoverFetchUnit &cpy )
-    : QSharedData( cpy )
-{
-    m_album = cpy.m_album;
-    m_options = cpy.m_options;
-
-    switch( cpy.m_payload->type() )
-    {
-        case CoverFetchPayload::Info:
-        {
-            m_payload = new CoverFetchInfoPayload( cpy.m_album, cpy.m_payload->source() );
-            break;
-        }
-        case CoverFetchPayload::Search:
-        {
-            typedef CoverFetchSearchPayload CFSP;
-            const CFSP *payload = dynamic_cast< const CFSP* >( cpy.payload() );
-            m_payload = new CoverFetchSearchPayload( payload->query() );
-            break;
-        }
-        case CoverFetchPayload::Art:
-        {
-            typedef CoverFetchArtPayload CFAP;
-            const CFAP *payload = dynamic_cast< const CFAP* >( cpy.payload() );
-            m_payload = new CoverFetchArtPayload( cpy.m_album,
-                                                  payload->imageSize(),
-                                                  payload->source(),
-                                                  payload->isWild() );
-            break;
-        }
-        default:
-            m_payload = 0;
-    }
-}
-
 CoverFetchUnit::~CoverFetchUnit()
 {
     delete m_payload;
@@ -142,47 +108,9 @@ CoverFetchUnit::addError( const T &error )
     m_errors << error;
 }
 
-CoverFetchUnit &CoverFetchUnit::operator=( const CoverFetchUnit &rhs )
-{
-    if( this == &rhs )
-        return *this;
-
-    switch( rhs.m_payload->type() )
-    {
-        case CoverFetchPayload::Info:
-        {
-            m_payload = new CoverFetchInfoPayload( rhs.m_album, rhs.payload()->source() );
-            break;
-        }
-        case CoverFetchPayload::Search:
-        {
-            typedef CoverFetchSearchPayload CFSP;
-            const CFSP *payload = dynamic_cast< const CFSP* >( rhs.payload() );
-            m_payload = new CoverFetchSearchPayload( payload->query() );
-            break;
-        }
-        case CoverFetchPayload::Art:
-        {
-            typedef CoverFetchArtPayload CFAP;
-            const CFAP *payload = dynamic_cast< const CFAP* >( rhs.payload() );
-            m_payload = new CoverFetchArtPayload( rhs.m_album,
-                                                  payload->imageSize(),
-                                                  payload->source(),
-                                                  payload->isWild() );
-            break;
-        }
-        default:
-            m_payload = 0;
-    }
-
-    m_album = rhs.m_album;
-    m_options = rhs.m_options;
-    return *this;
-}
-
 bool CoverFetchUnit::operator==( const CoverFetchUnit &other ) const
 {
-    return m_album == other.m_album;
+    return (m_album == other.m_album) && (m_options == other.m_options) && (m_payload == other.m_payload);
 }
 
 bool CoverFetchUnit::operator!=( const CoverFetchUnit &other ) const
@@ -281,11 +209,18 @@ CoverFetchInfoPayload::CoverFetchInfoPayload( const Meta::AlbumPtr album, const
     prepareUrls();
 }
 
-CoverFetchInfoPayload::CoverFetchInfoPayload( const CoverFetch::Source src, const QByteArray &xml )
+CoverFetchInfoPayload::CoverFetchInfoPayload( const CoverFetch::Source src, const QByteArray &data )
     : CoverFetchPayload( Meta::AlbumPtr( 0 ), CoverFetchPayload::Info, src )
-    , m_xml( QString::fromUtf8( xml ) )
 {
-    prepareUrls();
+    switch( src )
+    {
+    default:
+        prepareUrls();
+        break;
+    case CoverFetch::Discogs:
+        prepareDiscogsUrls( data );
+        break;
+    }
 }
 
 CoverFetchInfoPayload::~CoverFetchInfoPayload()
@@ -317,49 +252,65 @@ CoverFetchInfoPayload::prepareUrls()
         metadata[ "source" ] = "Last.fm";
         metadata[ "method" ] = method();
         break;
-
-    case CoverFetch::Discogs:
-        QDomDocument doc;
-        if( doc.setContent( m_xml ) )
-            prepareDiscogsUrls( doc );
-        break;
     }
-    m_urls.insert( url, metadata );
+
+    if( url.isValid() )
+        m_urls.insert( url, metadata );
 }
 
 void
-CoverFetchInfoPayload::prepareDiscogsUrls( const QDomDocument &doc )
+CoverFetchInfoPayload::prepareDiscogsUrls( const QByteArray &data )
 {
-    const QDomElement &docElem = doc.documentElement();
-
-    const QDomNode &respNode = docElem.namedItem( "resp" );
-    if( respNode.hasAttributes() )
+    QXmlStreamReader xml( QString::fromUtf8(data) );
+    while( !xml.atEnd() && !xml.hasError() )
     {
-        const QString &stat = respNode.attributes().namedItem( "stat" ).nodeValue();
-        if( stat != "ok" )
-            return;
-    }
+        xml.readNext();
+        if( xml.isStartElement() && xml.name() == "searchresults" )
+        {
+            while( !xml.atEnd() && !xml.hasError() )
+            {
+                xml.readNext();
+                const QStringRef &n = xml.name();
+                if( xml.isEndElement() && n == "searchresults" )
+                    break;
+                if( !xml.isStartElement() )
+                    continue;
+                if( n == "result" )
+                {
+                    while( !xml.atEnd() && !xml.hasError() )
+                    {
+                        xml.readNext();
+                        if( xml.isEndElement() && n == "result" )
+                            break;
+                        if( !xml.isStartElement() )
+                            continue;
+                        if( xml.name() == "uri" )
+                        {
+                            KUrl releaseUrl( xml.readElementText() );
+                            QString releaseStr = releaseUrl.url( KUrl::RemoveTrailingSlash );
+                            QString releaseId = releaseStr.split( '/' ).last();
 
-    const QDomNodeList &results = docElem.namedItem( "searchresults" ).childNodes();
-    for( uint x = 0, len = results.length(); x < len; ++x )
-    {
-        const QDomNode resultNode = results.item( x );
-        const KUrl releaseUrl     = resultNode.namedItem( "uri" ).toElement().text();
-        const QString releaseStr  = releaseUrl.url( KUrl::RemoveTrailingSlash );
-        const QString releaseId   = releaseStr.split( '/' ).last();
+                            KUrl url;
+                            url.setScheme( "http" );
+                            url.setHost( "www.discogs.com" );
+                            url.setPath( "/release/" + releaseId );
+                            url.addQueryItem( "api_key", Amarok::discogsApiKey() );
+                            url.addQueryItem( "f", "xml" );
 
-        KUrl url;
-        url.setScheme( "http" );
-        url.setHost( "www.discogs.com" );
-        url.setPath( "/release/" + releaseId );
-        url.addQueryItem( "api_key", Amarok::discogsApiKey() );
-        url.addQueryItem( "f", "xml" );
+                            CoverFetch::Metadata metadata;
+                            metadata[ "source" ] = "Discogs";
 
-        if( !url.isValid() )
-            continue;
-
-        CoverFetch::Metadata metadata;
-        m_urls.insert( url, metadata );
+                            if( url.isValid() )
+                                m_urls.insert( url, metadata );
+                        }
+                        else
+                            xml.skipCurrentElement();
+                    }
+                }
+                else
+                    xml.skipCurrentElement();
+            }
+        }
     }
 }
 
@@ -369,8 +320,9 @@ CoverFetchInfoPayload::prepareDiscogsUrls( const QDomDocument &doc )
 
 CoverFetchSearchPayload::CoverFetchSearchPayload( const QString &query,
                                                   const CoverFetch::Source src,
-                                                  unsigned int page )
-    : CoverFetchPayload( Meta::AlbumPtr( 0 ), CoverFetchPayload::Search, src )
+                                                  unsigned int page,
+                                                  Meta::AlbumPtr album )
+    : CoverFetchPayload( album, CoverFetchPayload::Search, src )
     , m_page( page )
     , m_query( query )
 {
@@ -441,7 +393,8 @@ CoverFetchSearchPayload::prepareUrls()
         break;
     }
 
-    m_urls.insert( url, metadata );
+    if( url.isValid() )
+        m_urls.insert( url, metadata );
 }
 
 /*
@@ -493,101 +446,103 @@ CoverFetchArtPayload::setXml( const QByteArray &xml )
 void
 CoverFetchArtPayload::prepareUrls()
 {
-    QDomDocument doc;
-    if( ( m_src != CoverFetch::Google ) && !doc.setContent( m_xml ) )
+    if( m_src == CoverFetch::Google )
     {
-        debug() << QString( "The xml obtained from %1 is invalid." ).arg( sourceString() );
+        // google is special
+        prepareGoogleUrls();
         return;
     }
 
+    QXmlStreamReader xml( m_xml );
     switch( m_src )
     {
+    default:
     case CoverFetch::LastFm:
-        prepareLastFmUrls( doc );
+        prepareLastFmUrls( xml );
         break;
     case CoverFetch::Yahoo:
-        prepareYahooUrls( doc );
-        break;
-    case CoverFetch::Google:
-        prepareGoogleUrls( m_xml );
+        prepareYahooUrls( xml );
         break;
     case CoverFetch::Discogs:
-        prepareDiscogsUrls( doc );
+        prepareDiscogsUrls( xml );
         break;
     }
+
+    if( xml.hasError() )
+    {
+        debug() << QString( "Error occured when pareparing %1 urls: %2" )
+                                .arg( sourceString(), xml.errorString() );
+    }
 }
 
 void
-CoverFetchArtPayload::prepareDiscogsUrls( const QDomDocument &doc )
+CoverFetchArtPayload::prepareDiscogsUrls( QXmlStreamReader &xml )
 {
-    const QDomElement &docElem = doc.documentElement();
-    const QDomNode &respNode = docElem.namedItem( "resp" );
-    if( respNode.hasAttributes() )
+    while( !xml.atEnd() && !xml.hasError() )
     {
-        const QString &stat = respNode.attributes().namedItem( "stat" ).nodeValue();
-        if( stat != "ok" )
-            return;
-    }
+        xml.readNext();
+        if( !xml.isStartElement() || xml.name() != "release" )
+            continue;
 
-    CoverFetch::Metadata metadata;
-    const QDomNode &releaseNode = docElem.namedItem( "release" );
-    if( releaseNode.hasAttributes() )
-    {
-        const QDomNamedNodeMap attr = releaseNode.attributes();
-        metadata[ "releaseid" ] = attr.namedItem( "id" ).nodeValue();
-    }
-
-    // TODO: there are a lot more discogs info that can be extracted as metadata.
-    metadata[ "notes" ] = releaseNode.namedItem( "notes" ).toElement().text();
-    metadata[ "title" ] = releaseNode.namedItem( "title" ).toElement().text();
-    metadata[ "country" ] = releaseNode.namedItem( "country" ).toElement().text();
-    metadata[ "released" ] = releaseNode.namedItem( "released" ).toElement().text();
-    metadata[ "source" ] = "Discogs";
-
-    const QDomNodeList imageNodes = releaseNode.namedItem( "images" ).childNodes();
-    for( uint x = 0, len = imageNodes.length(); x < len; ++x )
-    {
-        const QDomNode &node = imageNodes.item( x );
-        if( node.hasAttributes() )
+        const QString releaseId = xml.attributes().value( "id" ).toString();
+        while( !xml.atEnd() && !xml.hasError() )
         {
-            const QDomNamedNodeMap attr = node.attributes();
-            const QString thburl = attr.namedItem( "uri150" ).nodeValue();
-            const KUrl uri       = attr.namedItem( "uri"    ).nodeValue();
-
-            KUrl url;
-            switch( m_size )
-            {
-            case CoverFetch::NormalSize:
-                url = uri;
+            xml.readNext();
+            const QStringRef &n = xml.name();
+            if( xml.isEndElement() && n == "release" )
                 break;
-            case CoverFetch::ThumbSize:
-            default:
-                url = KUrl( thburl );
-                break;
-            }
-
-            if( !url.isValid() )
+            if( !xml.isStartElement() )
                 continue;
 
-            const QString height = attr.namedItem( "height" ).nodeValue();
-            const QString width  = attr.namedItem( "width"  ).nodeValue();
-            const QString type   = attr.namedItem( "type"   ).nodeValue();
-            const QString relUrl = "http://discogs.com/release/" + metadata.value( "releaseid" );
+            CoverFetch::Metadata metadata;
+            metadata[ "source" ] = "Discogs";
+            if( n == "title" )
+                metadata[ "title" ] = xml.readElementText();
+            else if( n == "country" )
+                metadata[ "country" ] = xml.readElementText();
+            else if( n == "released" )
+                metadata[ "released" ] = xml.readElementText();
+            else if( n == "notes" )
+                metadata[ "notes" ] = xml.readElementText();
+            else if( n == "images" )
+            {
+                while( !xml.atEnd() && !xml.hasError() )
+                {
+                    xml.readNext();
+                    if( xml.isEndElement() && xml.name() == "images" )
+                        break;
+                    if( !xml.isStartElement() )
+                        continue;
+                    if( xml.name() == "image" )
+                    {
+                        const QXmlStreamAttributes &attr = xml.attributes();
+                        const KUrl thburl( attr.value( "uri150" ).toString() );
+                        const KUrl uri( attr.value( "uri" ).toString() );
+                        const KUrl url = (m_size == CoverFetch::ThumbSize) ? thburl : uri;
+                        if( !url.isValid() )
+                            continue;
 
-            metadata[ "releaseurl"   ] = relUrl;
-            metadata[ "normalarturl" ] = uri.url();
-            metadata[ "thumbarturl"  ] = thburl;
-            metadata[ "width"        ] = width;
-            metadata[ "height"       ] = height;
-            metadata[ "type"         ] = type;
-
-            m_urls.insert( url, metadata );
+                        metadata[ "releaseid"    ] = releaseId;
+                        metadata[ "releaseurl"   ] = "http://discogs.com/release/" + releaseId;
+                        metadata[ "normalarturl" ] = uri.url();
+                        metadata[ "thumbarturl"  ] = thburl.url();
+                        metadata[ "width"        ] = attr.value( "width"  ).toString();
+                        metadata[ "height"       ] = attr.value( "height" ).toString();
+                        metadata[ "type"         ] = attr.value( "type"   ).toString();
+                        m_urls.insert( url, metadata );
+                    }
+                    else
+                        xml.skipCurrentElement();
+                }
+            }
+            else
+                xml.skipCurrentElement();
         }
     }
 }
 
 void
-CoverFetchArtPayload::prepareGoogleUrls( const QString &html )
+CoverFetchArtPayload::prepareGoogleUrls()
 {
     // code based on Audex CDDA Extractor
     const QString filter = "a-zA-Z0-9\\&\\_\\%\\/\\=\\.\\:\\-\\?\\,\\(\\)\\~\\!";
@@ -595,6 +550,7 @@ CoverFetchArtPayload::prepareGoogleUrls( const QString &html )
     rx.setMinimal( true );
 
     int pos = 0;
+    QString html = m_xml;
     while( ( (pos = rx.indexIn( html, pos ) ) != -1 ) )
     {
         KUrl url( "http://www.google.com" + rx.cap( 1 ) );
@@ -610,14 +566,15 @@ CoverFetchArtPayload::prepareGoogleUrls( const QString &html )
         if( !rx.cap( 2 ).isEmpty() )
             metadata[ "thumbarturl" ] = rx.cap( 2 );
 
+        url.clear();
         switch( m_size )
         {
-        case CoverFetch::NormalSize:
-            url = metadata.value( "normalarturl" );
-            break;
-        case CoverFetch::ThumbSize:
         default:
-            url = metadata.value( "thumbarturl" );
+        case CoverFetch::ThumbSize:
+            url = KUrl( metadata.value( "thumbarturl" ) );
+            break;
+        case CoverFetch::NormalSize:
+            url = KUrl( metadata.value( "normalarturl" ) );
             break;
         }
 
@@ -629,169 +586,142 @@ CoverFetchArtPayload::prepareGoogleUrls( const QString &html )
 }
 
 void
-CoverFetchArtPayload::prepareLastFmUrls( const QDomDocument &doc )
+CoverFetchArtPayload::prepareLastFmUrls( QXmlStreamReader &xml )
 {
-    QString albumArtist;
-    QDomNodeList results;
-    QSet< QString > artistSet;
-    const QString &searchMethod = method();
-
-    if( searchMethod == "album.getinfo" )
+    QSet<QString> artistSet;
+    if( method() == "album.getinfo" )
     {
-        results = doc.documentElement().childNodes();
-        albumArtist = normalize( album()->albumArtist()->name() );
+        artistSet << normalize( album()->albumArtist()->name() );
     }
-    else if( searchMethod == "album.search" )
+    else if( method() == "album.search" )
     {
-        results = doc.documentElement().namedItem( "results" ).namedItem( "albummatches" ).childNodes();
-
         if( !m_wild && album() )
         {
             const Meta::TrackList tracks = album()->tracks();
             QStringList artistNames( "Various Artists" );
             foreach( const Meta::TrackPtr &track, tracks )
-            {
                 artistNames << track->artist()->name();
-            }
             artistSet = normalize( artistNames ).toSet();
         }
     }
     else return;
 
-    for( uint x = 0, len = results.length(); x < len; ++x )
+    while( !xml.atEnd() && !xml.hasError() )
     {
-        const QDomNode albumNode = results.item( x );
-        const QString artist = normalize( albumNode.namedItem( "artist" ).toElement().text() );
-
-        if( searchMethod == "album.getinfo" && artist != albumArtist )
-            continue;
-        else if( searchMethod == "album.search" && !m_wild && !artistSet.contains( artist ) )
+        xml.readNext();
+        if( !xml.isStartElement() || xml.name() != "album" )
             continue;
 
-        KUrl url;
+        QHash<QString, QString> coverUrlHash;
         CoverFetch::Metadata metadata;
         metadata[ "source" ] = "Last.fm";
-
-        const QDomNodeList list = albumNode.childNodes();
-        for( int i = 0, count = list.count(); i < count; ++i )
+        while( !xml.atEnd() && !xml.hasError() )
         {
-            const QDomNode &node = list.item( i );
-            if( node.nodeName() == "image" && node.hasAttributes() )
+            xml.readNext();
+            const QStringRef &n = xml.name();
+            if( xml.isEndElement() && n == "album" )
+                break;
+            if( !xml.isStartElement() )
+                continue;
+
+            if( n == "name" )
             {
-                if( !node.isElement() )
+                metadata[ "name" ] = xml.readElementText();
+            }
+            else if( n == "artist" )
+            {
+                const QString &artist = xml.readElementText();
+                if( !artistSet.contains( artist ) )
                     continue;
-
-                const QString elementText = node.toElement().text();
-                const QString sizeStr = node.attributes().namedItem( "size" ).nodeValue();
-                enum CoverFetch::ImageSize imageSize = str2CoverSize( sizeStr );
-
-                switch( imageSize )
-                {
-                case CoverFetch::ThumbSize:
-                    metadata[ "thumbarturl" ] = elementText;
-                    break;
-                case CoverFetch::NormalSize:
-                    metadata[ "normalarturl" ] = elementText;
-                    break;
-                default:
-                    continue;
-                }
-
-                if( m_size == imageSize )
-                    url = elementText;
+                metadata[ "artist" ] = artist;
+            }
+            else if( n == "url" )
+            {
+                metadata[ "releaseurl" ] = xml.readElementText();
+            }
+            else if( n == "image" )
+            {
+                QString sizeStr = xml.attributes().value("size").toString();
+                coverUrlHash[ sizeStr ] = xml.readElementText();
             }
         }
 
-        if( !url.isValid() )
-            continue;
+        QStringList acceptableSizes;
+        acceptableSizes << "large" << "medium" << "small";
+        metadata[ "thumbarturl" ] = firstAvailableValue( acceptableSizes, coverUrlHash );
 
-        QStringList tags;
-        tags << "name" << "artist";
-        foreach( const QString &tag, tags )
-        {
-            const QDomElement e = albumNode.namedItem( tag ).toElement();
-            if( !e.isNull() )
-                metadata[ tag ] = e.text();
-        }
+        acceptableSizes.clear();
+        acceptableSizes << "extralarge" << "large";
+        metadata[ "normalarturl" ] = firstAvailableValue( acceptableSizes, coverUrlHash );
 
-        const QDomElement urlElem = albumNode.namedItem( "url" ).toElement();
-        if( !urlElem.isNull() )
-            metadata[ "releaseurl" ] = urlElem.text();
-
-        m_urls.insert( url, metadata );
-    }
-}
-
-void
-CoverFetchArtPayload::prepareYahooUrls( const QDomDocument &doc )
-{
-    const QDomNodeList results = doc.documentElement().namedItem( "resultset_images" ).childNodes();
-    for( uint x = 0, len = results.length(); x < len; ++x )
-    {
-        const QDomNode albumNode = results.item( x );
-        const KUrl url = albumNode.namedItem( coverSize2str( imageSize() ) ).toElement().text();
-        if( !url.isValid() )
-            continue;
-
-        CoverFetch::Metadata metadata;
-        metadata[ "source" ] = "Yahoo!";
-        metadata[ "thumbarturl" ] = albumNode.namedItem( "thumbnail_url" ).toElement().text();
-        metadata[ "normalarturl" ] = albumNode.namedItem( "url" ).toElement().text();
-
-        const QDomNodeList list = albumNode.childNodes();
-        for( int i = 0, count = list.count(); i < count; ++i )
-        {
-            const QDomNode &node = list.item( i );
-            if( node.isElement() )
-            {
-                const QDomElement element = node.toElement();
-                const QString elementText = element.text();
-                const QString elementTag  = element.tagName();
-                metadata[ elementTag ] = elementText;
-            }
-        }
-
-        if( metadata.contains( "abstract" ) )
-        {
-            const QString notes = metadata.take( "abstract" );
-            metadata[ "notes" ] = notes;
-        }
-        m_urls.insert( url, metadata );
+        KUrl url( m_size == CoverFetch::ThumbSize ? metadata["thumbarturl"] : metadata["normalarturl"] );
+        if( url.isValid() )
+            m_urls.insert( url , metadata );
     }
 }
 
 QString
-CoverFetchArtPayload::coverSize2str( enum CoverFetch::ImageSize size ) const
+CoverFetchArtPayload::firstAvailableValue( const QStringList &keys, const QHash<QString, QString> &hash )
 {
-    QString str;
-    switch( size )
+    for( int i = 0, size = keys.size(); i < size; ++i )
     {
-    case CoverFetch::ThumbSize:
-        if( m_src == CoverFetch::LastFm )
-            str = "large"; // around 128x128
-        else if( m_src == CoverFetch::Yahoo )
-            str = "thumbnail_url";
-        break;
-    case CoverFetch::NormalSize:
-    default:
-        if( m_src == CoverFetch::LastFm )
-            str = "extralarge"; // up to 300x300
-        else if( m_src == CoverFetch::Yahoo )
-            str = "url";
-        break;
+        QString value( hash.value( keys.at(i) ) );
+        if( !value.isEmpty() )
+            return value;
     }
-    return str;
+    return QString();
 }
 
-enum CoverFetch::ImageSize
-CoverFetchArtPayload::str2CoverSize( const QString &string ) const
+void
+CoverFetchArtPayload::prepareYahooUrls( QXmlStreamReader &xml )
 {
-    enum CoverFetch::ImageSize size;
-    if( string == "large" || string == "thumbnail_url" )
-        size = CoverFetch::ThumbSize;
-    else
-        size = CoverFetch::NormalSize;
-    return size;
+    while( !xml.atEnd() && !xml.hasError() )
+    {
+        xml.readNext();
+        if( !xml.isStartElement() || xml.name() != "resultset_images" )
+            continue;
+
+        while( !xml.atEnd() && !xml.hasError() )
+        {
+            xml.readNext();
+            if( xml.isEndElement() && xml.name() == "resultset_images" )
+                break;
+            if( !xml.isStartElement() )
+                continue;
+
+            CoverFetch::Metadata metadata;
+            metadata[ "source" ] = "Yahoo!";
+            if( xml.name() == "result" )
+            {
+                while( !xml.atEnd() && !xml.hasError() )
+                {
+                    xml.readNext();
+                    const QStringRef &n = xml.name();
+                    if( xml.isEndElement() && n == "result" )
+                        break;
+                    if( !xml.isStartElement() )
+                        continue;
+
+                    if( n == "abstract" )
+                        metadata[ "notes" ] = xml.readElementText();
+                    else if( n == "thumbnail_url" )
+                        metadata[ "thumbarturl" ] = xml.readElementText();
+                    else if( n == "url" )
+                        metadata[ "normalarturl" ] = xml.readElementText();
+                    else
+                        metadata[ xml.name().toString() ] = xml.readElementText();
+                }
+
+                KUrl url = (imageSize() == CoverFetch::ThumbSize)
+                    ? KUrl( metadata["thumbarturl"] )
+                    : KUrl( metadata["normalarturl"] );
+                if( url.isValid() )
+                    m_urls.insert( url, metadata );
+            }
+            else
+                xml.skipCurrentElement();
+        }
+    }
 }
 
 QString
