@@ -691,9 +691,9 @@ ScriptManager::findScripts()
         else if ( m_scripts[key].info.category() == "Scriptable Service" )
             ServiceInfoList.append( m_scripts[key].info );
     }
-    m_scriptSelector->addScripts( GenericInfoList, KPluginSelector::ReadConfigFile, "Generic" );
-    m_scriptSelector->addScripts( LyricsInfoList, KPluginSelector::ReadConfigFile, "Lyrics" );
-    m_scriptSelector->addScripts( ServiceInfoList, KPluginSelector::ReadConfigFile, "Scriptable Service" );
+    m_scriptSelector->addScripts( GenericInfoList, KPluginSelector::ReadConfigFile, i18n( "Generic" ) );
+    m_scriptSelector->addScripts( LyricsInfoList, KPluginSelector::ReadConfigFile, i18n( "Lyrics" ) );
+    m_scriptSelector->addScripts( ServiceInfoList, KPluginSelector::ReadConfigFile, i18n( "Scriptable Service" ) );
 
     // Handle auto-run:
     slotConfigChanged( true );
