@@ -9,7 +9,7 @@
  *                                                                                      *
  * This program is distributed in the hope that it will be useful, but WITHOUT ANY      *
  * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A      *
- * PARTICULAR PURPOSE. See the GNU General Public License for more details.              *
+ * PARTICULAR PURPOSE. See the GNU General Public License for more details.             *
  *                                                                                      *
  * You should have received a copy of the GNU General Public License along with         *
  * this program.  If not, see <http://www.gnu.org/licenses/>.                           *
@@ -17,13 +17,12 @@
 
 #include "deviceconfiguredialog.h"
 
-#include "Amarok.h"
-#include "Debug.h"
+#include "core/support/Amarok.h"
+#include "core/support/Debug.h"
 #include "hintlineedit.h"
 #include "mediabrowser.h"
 #include "MediaDevice.h"
-#include "plugin/pluginconfig.h"
-#include "PluginManager.h"
+#include "core/plugins/PluginManager.h"
 #include "ScriptManager.h"
 
 #include <KLocale>
