@@ -30,13 +30,14 @@
 #include "core/meta/support/MetaConstants.h"
 #include "core/collections/MetaQueryMaker.h"
 #include "core/collections/QueryMaker.h"
+#include "core-impl/collections/support/XmlQueryReader.h"
 #include "core-impl/collections/support/XmlQueryWriter.h"
 
 #include <QMutexLocker>
+#include <QDateTime>
 
 #include <cmath>
 
-
 // defined in gsl/gauss.c
 extern "C" {
 double gsl_cdf_gaussian_P( const double x, const double sigma );
@@ -59,34 +60,17 @@ Dynamic::Bias::fromXml( QDomElement e )
 
     if( type == "global" )
     {
-        double weight = 0.0;
-        XmlQueryReader::Filter filter;
-
-
-        QDomElement queryElement = e.firstChildElement( "query" );
-        if( !queryElement.isNull() )
-        {
-            // I don't actually need a qm from XmlQueryReader, I just want the filters.
-            Collections::QueryMaker* dummyQM = new Collections::MetaQueryMaker( QList<Collections::QueryMaker*>() );
-
-            QString rawXml;
-            QTextStream rawXmlStream( &rawXml );
-            queryElement.save( rawXmlStream, 0 );
-            XmlQueryReader reader( dummyQM, XmlQueryReader::IgnoreReturnValues );
-            reader.read( rawXml );
-            if( reader.getFilters().size() > 0 )
-                filter = reader.getFilters().first();
-
-            delete dummyQM;
-        }
-
-        QDomElement weightElement = e.firstChildElement( "weight" );
-        if( !weightElement.isNull() )
-        {
-            weight = weightElement.attribute("value").toDouble();
-        }
-
-        return new Dynamic::GlobalBias( weight, filter );
+        return Dynamic::GlobalBias::fromXml( e );
+#if QT_VERSION >= 0x040600
+#else
+                    // QXmlStreamReader::readNextStartElement doesn't exist in Qt-4.5
+                    // this is the inlined method body, adapted from lines 656 - 665 of
+                    // http://qt.gitorious.org/qt/qt/blobs/4.6/src/corelib/xml/qxmlstream.cpp
+                    while ( reader.readNext() != QXmlStreamReader::Invalid ) {
+                        if ( reader.isEndElement() || reader.isStartElement() )
+                            break;
+                    }
+#endif
     }
     else if( type == "custom" )
     {
@@ -197,19 +181,19 @@ Dynamic::CollectionDependantBias::collectionUpdated()
     m_needsUpdating = true;
 }
 
-Dynamic::GlobalBias::GlobalBias( double weight, XmlQueryReader::Filter filter )
+Dynamic::GlobalBias::GlobalBias( double weight, Filter filter )
     : m_qm(0)
 {
     setWeight( weight );
-    setQuery( filter );
+    setFilter( filter );
 }
 
-Dynamic::GlobalBias::GlobalBias( Collections::Collection* coll, double weight, XmlQueryReader::Filter filter )
+Dynamic::GlobalBias::GlobalBias( Collections::Collection* coll, double weight, Filter filter )
     : CollectionDependantBias( coll )
     , m_qm(0)
 {
     setWeight( weight );
-    setQuery( filter );
+    setFilter( filter );
 }
 
 Dynamic::GlobalBias::~GlobalBias()
@@ -217,6 +201,68 @@ Dynamic::GlobalBias::~GlobalBias()
     delete m_qm;
 }
 
+QString
+Dynamic::GlobalBias::filterConditionToString( Dynamic::GlobalBias::FilterCondition cond )
+{
+    switch( cond )
+    {
+        case Equals:
+            return "equals";
+        case GreaterThan:
+            return "greater";
+        case LessThan:
+            return "less";
+        case Between:
+            return "between";
+        case OlderThan:
+            return "older";
+        case Contains:
+            return "contains";
+    }
+    return QString();
+}
+
+Dynamic::GlobalBias*
+Dynamic::GlobalBias::fromXml( QDomElement e )
+{
+    double weight = 0.0;
+    Dynamic::GlobalBias::Filter filter;
+
+    QDomElement queryElement = e.firstChildElement( "query" );
+    if( !queryElement.isNull() )
+    {
+        QDomElement filtersElement = queryElement.firstChildElement( "filters" );
+        if( !filtersElement.isNull() )
+        {
+            QDomElement includeElement = filtersElement.firstChildElement( "include" );
+            if( !includeElement.isNull() )
+            {
+                QString field = includeElement.attribute("field");
+                filter.field = XmlQueryReader::fieldVal( QStringRef(&field) );
+                filter.value = includeElement.attribute( "value", "" );
+                filter.numValue = filter.value.toLongLong();
+                filter.numValue2 = includeElement.attribute( "value2", 0 ).toLongLong();
+
+                QString condition = includeElement.attribute( "compare", "" );
+                filter.condition = Contains;
+                for( int i=0; i<5; i++ )
+                {
+                    if( condition == filterConditionToString( (FilterCondition)i ) )
+                        filter.condition = (FilterCondition)i;
+                }
+            }
+        }
+    }
+
+    QDomElement weightElement = e.firstChildElement( "weight" );
+    if( !weightElement.isNull() )
+    {
+        weight = weightElement.attribute("value").toDouble();
+    }
+
+    return new Dynamic::GlobalBias( weight, filter );
+}
+
 QDomElement
 Dynamic::GlobalBias::xml() const
 {
@@ -228,9 +274,22 @@ Dynamic::GlobalBias::xml() const
 
     QDomElement weight = doc.createElement( "weight" );
     weight.setAttribute( "value", QString::number( m_weight ) );
-
     e.appendChild( weight );
-    e.appendChild( m_qm->getDomElement() );
+
+    QDomElement queryElement = doc.createElement( "query" );
+    QDomElement filtersElement = doc.createElement( "filters" );
+    QDomElement includeElement = doc.createElement( "include" );
+    includeElement.setAttribute( "field", Collections::XmlQueryWriter::fieldName( m_filter.field ) );
+    if( m_filter.condition == Contains )
+        includeElement.setAttribute( "value", m_filter.value );
+    else
+        includeElement.setAttribute( "value", QString::number( m_filter.numValue ) );
+    includeElement.setAttribute( "value2", QString::number( m_filter.numValue2 ) );
+    includeElement.setAttribute( "compare", filterConditionToString( m_filter.condition ) );
+
+    filtersElement.appendChild( includeElement );
+    queryElement.appendChild( filtersElement );
+    e.appendChild( queryElement );
 
     return e;
 }
@@ -242,12 +301,6 @@ Dynamic::GlobalBias::widget( QWidget* parent )
     return new PlaylistBrowserNS::BiasGlobalWidget( this, parent );
 }
 
-const XmlQueryReader::Filter&
-Dynamic::GlobalBias::filter() const
-{
-    return m_filter;
-}
-
 double
 Dynamic::GlobalBias::weight() const
 {
@@ -277,8 +330,15 @@ Dynamic::CollectionFilterCapability* Dynamic::GlobalBias::collectionFilterCapabi
 }
 
 
+
+Dynamic::GlobalBias::Filter
+Dynamic::GlobalBias::filter() const
+{
+    return m_filter;
+}
+
 void
-Dynamic::GlobalBias::setQuery( XmlQueryReader::Filter filter )
+Dynamic::GlobalBias::setFilter( const Filter &filter)
 {
     DEBUG_BLOCK
     QMutexLocker locker( &m_mutex );
@@ -289,16 +349,32 @@ Dynamic::GlobalBias::setQuery( XmlQueryReader::Filter filter )
     if (m_qm)
         delete m_qm;
 
-    m_qm = new Collections::XmlQueryWriter( m_collection->queryMaker(),
-            QDomDocument() );
+    m_qm = m_collection->queryMaker();
 
     if( filter.field != 0 )
     {
-        if( filter.compare == -1 )
+        switch( filter.condition )
+        {
+        case Equals:
+        case GreaterThan:
+        case LessThan:
+            m_qm->addNumberFilter( filter.field, filter.numValue,
+                    (Collections::QueryMaker::NumberComparison)filter.condition );
+            break;
+        case Between:
+            m_qm->addNumberFilter( filter.field, qMin(filter.numValue, filter.numValue2)-1,
+                    Collections::QueryMaker::GreaterThan );
+            m_qm->addNumberFilter( filter.field, qMax(filter.numValue, filter.numValue2)+1,
+                    Collections::QueryMaker::LessThan );
+            break;
+        case OlderThan:
+            m_qm->addNumberFilter( filter.field, QDateTime::currentDateTime().toTime_t() - filter.numValue,
+                    Collections::QueryMaker::LessThan );
+            break;
+
+        case Contains:
             m_qm->addFilter( filter.field, filter.value );
-        else
-            m_qm->addNumberFilter( filter.field, filter.value.toLongLong(),
-                    (Collections::QueryMaker::NumberComparison)filter.compare );
+        }
     }
 
     m_qm->setQueryType( Collections::QueryMaker::Custom );
@@ -322,6 +398,8 @@ Dynamic::GlobalBias::energy( const Meta::TrackList& playlist, const Meta::TrackL
 {
     Q_UNUSED( context );
 
+    // TODO: for lastPlayed we should check the context and the songs already in the playlist
+
     double satisfiedCount = 0;
     foreach( Meta::TrackPtr t, playlist )
     {
@@ -338,6 +416,7 @@ double Dynamic::GlobalBias::reevaluate( double oldEnergy, const Meta::TrackList&
 {
     Q_UNUSED( context );
 
+    // TODO: for lastPlayed we should check the context and the songs already in the playlist
     double offset = 1.0 / (double)oldPlaylist.size();
 
     bool prevSatisfied = trackSatisfies( oldPlaylist[newTrackPos] );
