@@ -3,6 +3,7 @@
  * Copyright (c) 2008 Seb Ruiz <ruiz@kde.org>                                           *
  * Copyright (c) 2008 Soren Harward <stharward@gmail.com>                               *
  * Copyright (c) 2008 Nikolaj Hald Nielsen <nhn@kde.org>                                *
+ * Copyright (c) 2010 Nanno Langstraat <langstr@gmail.com>                              *
  *                                                                                      *
  * This program is free software; you can redistribute it and/or modify it under        *
  * the terms of the GNU General Public License as published by the Free Software        *
@@ -23,9 +24,9 @@
 #define AMAROK_PLAYLISTMODEL_H
 
 #include "proxymodels/AbstractModel.h"
-#include "Amarok.h"
+#include "core/support/Amarok.h"
 #include "UndoCommands.h"
-#include "meta/Meta.h"
+#include "core/meta/Meta.h"
 
 #include <QAbstractListModel>
 #include <QHash>
@@ -36,16 +37,18 @@
 class AmarokMimeData;
 class QMimeData;
 class QModelIndex;
+class TestPlaylistModels;
 
 
 namespace Playlist
 {
 
-class AMAROK_EXPORT Model : public QAbstractListModel, public Meta::Observer, public AbstractModel
+class AMAROK_EXPORT Model : public QAbstractListModel, public Meta::Observer, public Playlist::AbstractModel
 {
     friend class InsertTracksCmd;
     friend class RemoveTracksCmd;
     friend class MoveTracksCmd;
+    friend class ::TestPlaylistModels; //this test really needs access to the private functions.
 
     Q_OBJECT
 
@@ -53,118 +56,86 @@ class AMAROK_EXPORT Model : public QAbstractListModel, public Meta::Observer, pu
         Model( QObject *parent = 0 );
         ~Model();
 
-        // inherited from QAbstractListModel
-        int rowCount( const QModelIndex& parent = QModelIndex() ) const { Q_UNUSED( parent ); return m_items.size(); }
+        // Inherited from QAbstractItemModel  (via QAbstractListModel)
         int columnCount( const QModelIndex& parent = QModelIndex() ) const { Q_UNUSED( parent ); return NUM_COLUMNS; }
-        QVariant headerData( int section, Qt::Orientation orientation, int role ) const;
         QVariant data( const QModelIndex& index, int role ) const;
-        Qt::DropActions supportedDropActions() const;
-        Qt::ItemFlags flags( const QModelIndex &index ) const;
-        QStringList mimeTypes() const;
-        QMimeData* mimeData( const QModelIndexList &indexes ) const;
         bool dropMimeData( const QMimeData* data, Qt::DropAction action, int row, int column, const QModelIndex& parent );
+        Qt::ItemFlags flags( const QModelIndex &index ) const;
+        QVariant headerData( int section, Qt::Orientation orientation, int role ) const;
+        QMimeData* mimeData( const QModelIndexList &indexes ) const;
+        QStringList mimeTypes() const;
+        int rowCount( const QModelIndex& parent = QModelIndex() ) const { Q_UNUSED( parent ); return m_items.size(); }
+        Qt::DropActions supportedDropActions() const;
 
-        // inherited from Meta::Observer
+        // Inherited from Playlist::AbstractModel
+        QAbstractItemModel* qaim() const { return const_cast<Model*>( this ); }
+
+        quint64 activeId() const;
+        int activeRow() const { return m_activeRow; } // returns -1 if there is no active row
+        QSet<int> allRowsForTrack( const Meta::TrackPtr track ) const;
+        Meta::TrackPtr activeTrack() const;
+        bool containsTrack( const Meta::TrackPtr track ) const;
+        inline const QString defaultPlaylistPath() const { return Amarok::saveLocation() + "current.xspf"; }
+        virtual bool exportPlaylist( const QString &path ) const;
+        int firstRowForTrack( const Meta::TrackPtr track ) const;
+        quint64 idAt( const int row ) const;
+        bool rowExists( int row ) const { return (( row >= 0 ) && ( row < m_items.size() ) ); }
+        int rowForId( const quint64 id ) const; // returns -1 if the id is invalid
+        int rowToBottomModel( const int row ) { return row; }
+        void setActiveId( const quint64 id ) { setActiveRow( rowForId( id ) ); }
+        void setActiveRow( int row );
+        void setAllNewlyAddedToUnplayed();
+        void setAllUnplayed();
+        void setRowQueued( int row );
+        void setRowDequeued( int row );
+        Item::State stateOfId( quint64 id ) const;
+        Item::State stateOfRow( int row ) const;
+        qint64 totalLength() const { return m_totalLength; }
+        quint64 totalSize() const { return m_totalSize; }
+        Meta::TrackPtr trackAt( int row ) const;
+        Meta::TrackPtr trackForId( const quint64 id ) const;
+        virtual Meta::TrackList tracks() const;
+
+        // Inherited from Meta::Observer
         using Observer::metadataChanged;
         void metadataChanged( Meta::TrackPtr track );
         void metadataChanged( Meta::AlbumPtr album );
 
-        qint64 totalLength() const { return m_totalLength; }
-        quint64 totalSize() const { return m_totalSize; }
-
-        // convenience access methods
-        bool rowExists( int row ) const { return (( row >= 0 ) && ( row < m_items.size() ) ); }
-        int activeRow() const { return m_activeRow; } // returns -1 if there is no active row
-        void setActiveRow( int row );
-        void setRowQueued( int row );
-        void setRowDequeued( int row );
-        Item::State stateOfRow( int row ) const;
-
-        bool containsTrack( const Meta::TrackPtr track ) const;
-        int firstRowForTrack( const Meta::TrackPtr track ) const;
-        QSet<int> allRowsForTrack( const Meta::TrackPtr track ) const;
-
-        Meta::TrackPtr trackAt( int row ) const;
-        Meta::TrackPtr activeTrack() const;
-
-        /**
-         * Get the ordered list of tracks from this model
-         */
-        virtual Meta::TrackList tracks() const;
-
-        // position-independent access methods
-        // these are useful when you care what tracks are in the playlist, but not what order they're in (eg, the Random Track navigator)
-        bool containsId( const quint64 id ) const { return m_itemIds.contains( id ); }
-        int rowForId( const quint64 id ) const; // returns -1 if the id is invalid
-        Meta::TrackPtr trackForId( const quint64 id ) const;
-
-        /**
-         * Returns the unique playlist id of the track at the requested row
-         * @param row the index in the playlist
-         * @return the id of the row specified, or 0 if the row does not exist
-         */
-        quint64 idAt( const int row ) const;
-
-        /**
-         * Returns the unique playlist item id of the active track
-         * (or 0 if no track is active).
-         * @return The playlist item's id.
-         */
-        quint64 activeId() const;
-
-        /**
-         * Set the active track based on the playlist id given.
-         * @param id the unique playlist id
-         */
-        void setActiveId( const quint64 id ) { setActiveRow( rowForId( id ) ); }
-
-        /**
-         * The Item state of the playlist track at the specified index
-         */
-        Item::State stateOfId( quint64 id ) const;
-
-        void setAllUnplayed();
-
-        // methods to save playlist to file
-        /**
-         * Saves a playlist to a specified location.
-         * @param path the path of the playlist file, as chosen by a FileDialog in MainWindow.
-         */
-        virtual bool exportPlaylist( const QString &path ) const;
-        inline const QString defaultPlaylistPath() const { return Amarok::saveLocation() + "current.xspf"; }
-
         // static member functions
-        static QString prettyColumnName( Column index ); //!takes a Column enum and returns its string name
-
-        int rowToBottomModel( const int row ) { return row; }
+        static QString prettyColumnName( Column index ); //!< takes a Column enum and returns its string name
 
     signals:
-        void insertedIds( const QList<quint64>& );
-        void beginRemoveIds();
-        void removedIds( const QList<quint64>& );
         void activeTrackChanged( quint64 );
-        void activeRowChanged( int );
-        void metadataUpdated();
         void queueChanged();
 
+    protected:
+        int rowForItem( Item *item ) const { return m_items.indexOf( item ); }
+
     private:
-        // inherit from QAbstractListModel, and make private so that nobody uses them
+        // Inherited from QAbstractItemModel. Make them private so that nobody is tempted to use them.
         bool insertRow( int, const QModelIndex& parent = QModelIndex() ) { Q_UNUSED( parent ); return false; }
         bool insertRows( int, int, const QModelIndex& parent = QModelIndex() ) { Q_UNUSED( parent ); return false; }
         bool removeRow( int, const QModelIndex& parent = QModelIndex() ) { Q_UNUSED( parent ); return false; }
         bool removeRows( int, int, const QModelIndex& parent = QModelIndex() ) { Q_UNUSED( parent ); return false; }
 
-        // these functions do the real work of modifying the playlist, and should be called ONLY by UndoCommands
+        // These functions do the real work of modifying the playlist, and should be called ONLY by UndoCommands
         void insertTracksCommand( const InsertCmdList& );
         void removeTracksCommand( const RemoveCmdList& );
         void moveTracksCommand( const MoveCmdList&, bool reverse = false );
         void clearCommand();
-        void setStateOfRow( int row, Item::State state ) { m_items.at( row )->setState( state ); }
 
-        QList<Item*> m_items;            //! list of tracks in order currently in the playlist
-        QHash<quint64, Item*> m_itemIds; //! maps track id's to items
+        // Always alter the state of a row via one of the following functions.
+        void setStateOfItem_batchStart();
+        void setStateOfItem_batchEnd();
+        void setStateOfItem( Item *item, int row, Item::State state );    // 'item' must equal 'm_items.at( row )'
+        void setStateOfItem( Item *item, Item::State state ) { setStateOfItem( item, rowForItem( item ), state ); }
+        void setStateOfRow( int row, Item::State state )     { setStateOfItem( m_items.at( row ), row, state ); }
 
-        int m_activeRow;                 //! the row being played
+        // Variables
+        QList<Item*> m_items;               //!< list of playlist items, in their "natural" (unsorted) order.
+        QHash<quint64, Item*> m_itemIds;    //!< maps playlist item ID to Item pointer.
+
+        int m_activeRow;    //!< the row being played
 
         qint64 m_totalLength;
         quint64 m_totalSize;
@@ -172,6 +143,8 @@ class AMAROK_EXPORT Model : public QAbstractListModel, public Meta::Observer, pu
         QString m_playlistName;
         bool m_proposeOverwriting;
 
+        int m_setStateOfItem_batchMinRow;    //!< For 'setStateOfItem_batch*()'
+        int m_setStateOfItem_batchMaxRow;
 };
 
 } // namespace Playlist
