@@ -1,5 +1,5 @@
 /****************************************************************************************
- * Copyright (c) 2009 Nikolaj Hald Nielsen <nhnFreespirit@gmail.com>                    *
+ * Copyright (c) 2009 Nikolaj Hald Nielsen <nhn@kde.org>                                *
  *                                                                                      *
  * This program is free software; you can redistribute it and/or modify it under        *
  * the terms of the GNU General Public License as published by the Free Software        *
@@ -32,7 +32,7 @@ class InlineEditorWidget : public KVBox
     Q_OBJECT
 
 public:
-    InlineEditorWidget( QWidget * parent, const QModelIndex &index, Playlist::PlaylistLayout layout, int groupMode );
+    InlineEditorWidget( QWidget * parent, const QModelIndex &index, Playlist::PlaylistLayout layout, bool hasHeader );
     ~InlineEditorWidget();
 
     QMap<int, QString> changedValues();
@@ -48,15 +48,14 @@ protected slots:
     void editValueChanged();
     void ratingValueChanged();
     void splitterMoved( int pos, int index );
-        
+
 private:
     void createChildWidgets();
     QPoint centerImage( const QPixmap&, const QRectF& ) const;
     bool eventFilter( QObject *obj, QEvent *event );
 
-    QModelIndex m_index;
+    QPersistentModelIndex m_index;
     Playlist::PlaylistLayout m_layout;
-    int m_groupMode;
 
     QMap<QWidget *, int> m_editorRoleMap;
     QMap<int, QString> m_changedValues;
