@@ -88,8 +88,12 @@ Playlist::PrettyListView::PrettyListView( QWidget* parent )
     setDropIndicatorShown( false ); // we draw our own drop indicator
     setEditTriggers ( SelectedClicked | EditKeyPressed );
     setAutoScroll( true );
+
     setVerticalScrollMode( ScrollPerPixel );
 
+    setMouseTracking( true );
+
+
     // Rendering adjustments
     setFrameShape( QFrame::NoFrame );
     setAlternatingRowColors( true) ;
@@ -338,7 +342,7 @@ Playlist::PrettyListView::showEvent( QShowEvent* event )
 void
 Playlist::PrettyListView::fixInvisible() //SLOT
 {
-    DEBUG_BLOCK
+    // DEBUG_BLOCK
 
     // Part 1: Palette change
     newPalette( palette() );
