@@ -55,11 +55,12 @@ class ConstraintNode : public QObject {
     Q_OBJECT
     public:
         enum NodeType { ConstraintGroupType, ConstraintType };
-        enum Operations { OperationInsert, OperationReplace, OperationDelete };
+        enum Operations { OperationInsert, OperationReplace, OperationDelete, OperationSwap };
 
         typedef struct {
             Operations operation;
             int place;
+            int other; // for swaps
             Meta::TrackPtr track;
         } Vote;
 
@@ -112,4 +113,4 @@ class ConstraintNode : public QObject {
         QList<ConstraintNode*> m_children;
 };
 
-#endif
\ No newline at end of file
+#endif
