@@ -39,7 +39,7 @@ var stationArray = new Array (
     new Station( "Digitally Imported - Chillout [Chill-Out]",           "http://di.fm/mp3/classictechno.pls" ),
     new Station( "Digitally Imported - Classic Techno [Techno]",        "http://di.fm/mp3/classictechno.pls" ),
     new Station( "Digitally Imported - Trance [Trance]",                "http://di.fm/mp3/trance.pls" ),
-    new Station( "Evolved.fm [Techno/Trance]",                          "http://vhost.desync.com/evolved.pls" ),
+    new Station( "Evolved.fm [Techno/Trance]",                          "http://www.evolved.fm/evolved.m3u" ),
     new Station( "Frequence 3 [Pop]",                                   "http://streams.frequence3.net/hd-mp3.m3u" ),
     new Station( "Kohina [Computer-Music]",                             "http://la.campus.ltu.se:8000/stream.ogg.m3u" ),
     new Station( "Mostly Classical [Classical]",                        "http://www.sky.fm/mp3/classical.pls" ),
@@ -48,7 +48,6 @@ var stationArray = new Array (
     new Station( "Nectarine Demoscene Radio [Computer-Music]",          "http://demovibes.de:8000/necta128.ogg" ),
     new Station( "Philosomatika [Psytrance]",                           "http://yp.shoutcast.com/sbin/tunein-station.pls?id=5628" ),
     new Station( "Proton Radio [House/Dance]",                          "http://protonradio.com/proton.m3u" ),
-    new Station( "Pure DJ [Trance]",                                    "http://www.puredj.com/etc/pls/192K.pls" ),
     new Station( "Radio Paradise [Rock/Pop/Alternative]",               "http://www.radioparadise.com/musiclinks/rp_128.m3u" ),
     new Station( "Raggakings [Reggae]",                                 "http://www.raggakings.net/listen.m3u" ),
     new Station( "SLAY Radio [C64 Remixes]",                            "http://www.slayradio.org/tune_in.php/128kbps/listen.m3u" ),
