@@ -188,7 +188,7 @@ LastFmTreeView::startDrag(Qt::DropActions supportedActions)
         PopupDropper * morePud = 0;
         if ( actions.count() > 1 )
         {
-            morePud = The::popupDropperFactory()->createPopupDropper( 0 );
+            morePud = The::popupDropperFactory()->createPopupDropper( 0, true );
 
             foreach( QAction * action, actions )
                 morePud->addItem( The::popupDropperFactory()->createItem( action ) );
