@@ -19,11 +19,11 @@
 
 #include "../DynamicServiceQueryMaker.h"
 
-#include "Meta.h"
+#include "core/meta/Meta.h"
 
 #include "ScriptableServiceCollection.h"
 
-using namespace Meta;
+namespace Collections {
 
 /**
 A query maker for fetching external data
@@ -62,14 +62,15 @@ protected slots:
 
     void slotScriptComplete( );
 
-
-protected:
+private slots:
 
     void fetchGenre();
     void fetchArtists();
     void fetchAlbums();
     void fetchTracks();
 
+protected:
+
     void handleResult( const Meta::GenreList &genres );
     void handleResult( const Meta::ArtistList &artists );
     void handleResult( const Meta::AlbumList &albums );
@@ -101,4 +102,6 @@ private:
  
 };
 
+} //namespace Collections
+
 #endif
