@@ -17,7 +17,6 @@
 #include "CompoundProgressBar.h"
 
 #include "core/support/Debug.h"
-#include "MainWindow.h"
 
 #include <KIcon>
 #include <KLocale>
@@ -75,7 +74,7 @@ void CompoundProgressBar::addProgressBar( ProgressBar * childBar, QObject *owner
     handleDetailsButton();
 }
 
-void CompoundProgressBar::endProgressOperation( const QObject * owner )
+void CompoundProgressBar::endProgressOperation( QObject *owner )
 {
     if ( !m_progressMap.contains( owner ) )
         return ;
