@@ -19,6 +19,7 @@
 
 #include "amarokconfig.h"
 
+#include "App.h"
 #include "ActionClasses.h"
 #include "core/support/Amarok.h"
 #include "EngineController.h"
@@ -162,7 +163,7 @@ MainToolbar::MainToolbar( QWidget *parent )
     m_slider = new Amarok::TimeSlider( info );
     connect( m_slider, SIGNAL( sliderReleased( int ) ), The::engineController(), SLOT( seek( int ) ) );
     connect( m_slider, SIGNAL( valueChanged( int ) ), SLOT( setLabelTime( int ) ) );
-    connect( m_slider, SIGNAL( moodbarUsageChanged(bool) ), this, SLOT( layoutProgressBar() ) );
+    connect( App::instance(), SIGNAL( settingsChanged() ), this, SLOT( layoutProgressBar() ) );
 
     m_remainingTimeLabel = new QLabel( info );
     m_remainingTimeLabel->setAlignment( Qt::AlignVCenter | Qt::AlignLeft );
