@@ -25,17 +25,32 @@
 class AmarokDockWidget : public QDockWidget
 {
     Q_OBJECT
+
 public:
-    AmarokDockWidget( const QString & title, QWidget * parent = 0, Qt::WindowFlags flags = 0 );
+    explicit AmarokDockWidget( const QString & title, QWidget * parent = 0, Qt::WindowFlags flags = 0 );
+
+    void setMovable( bool movable );
 
 signals:
     void layoutChanged();
 
+protected slots:
+    void slotVisibilityChanged( bool visible );
+
 protected:
     virtual void closeEvent( QCloseEvent* );
     virtual void resizeEvent( QResizeEvent* );
     virtual void showEvent( QShowEvent* );
     virtual void hideEvent( QHideEvent* );
+
+    virtual void polish() = 0;
+    void ensurePolish();
+
+    bool m_polished;
+
+    QWidget * m_dummyTitleBarWidget;
+
+
 };
 
 #endif // AMAROKDOCKWIDGET_H
