@@ -20,7 +20,6 @@
 #define VOLUMEWIDGET_H
 
 #include "core/engine/EngineObserver.h"
-#include "SliderWidget.h"
 #include "ToolBar.h"
 
 #include <KAction>
@@ -28,6 +27,11 @@
 #include <QPointer>
 #include <QStringList>
 
+namespace Amarok
+{
+    class VolumeSlider;
+}
+
 /**
 * A custom widget that serves as our volume slider within Amarok.
 */
