@@ -379,12 +379,10 @@ CollectionScanner::readDir( const QString& dir, QStringList& entries )
     QStringList recurseDirs;
     foreach( const QFileInfo &fi, list )
     {
-        if( !fi.exists() )
+        if( !fi.exists() || ( fi.isSymLink() && !QFileInfo( fi.symLinkTarget() ).exists() ) )
             break;
 
-        const QFileInfo &f = fi.isSymLink() ? QFileInfo( fi.symLinkTarget() ) : fi;
-
-        if( f.isDir() && m_recursively && !m_scannedFolders.contains( f.canonicalFilePath() ) )
+        if( fi.isDir() && m_recursively && !m_scannedFolders.contains( fi.absoluteFilePath() ) )
         {
             //The following D-Bus call is used to see if a found folder is new or not
             //During an incremental scan the scanning isn't really recursive, as all folders
@@ -395,16 +393,16 @@ CollectionScanner::readDir( const QString& dir, QStringList& entries )
             bool isInCollection = false;
             if( m_incremental && m_amarokCollectionInterface )
             {
-                QDBusReply<bool> reply = m_amarokCollectionInterface->call( "isDirInCollection", f.canonicalFilePath() );
+                QDBusReply<bool> reply = m_amarokCollectionInterface->call( "isDirInCollection", fi.absoluteFilePath() );
                 if( reply.isValid() )
                     isInCollection = reply.value();
             }
 
             if( !m_incremental || !isInCollection )
-                recurseDirs << QString( f.absoluteFilePath() + '/' );
+                recurseDirs << QString( fi.absoluteFilePath() + '/' );
         }
-        else if( f.isFile() )
-            entries.append( f.absoluteFilePath() );
+        else if( fi.isFile() )
+            entries.append( fi.absoluteFilePath() );
     }
     foreach( const QString &dir, recurseDirs )
         readDir( dir, entries );
@@ -828,17 +826,17 @@ CollectionScanner::writeElement( const QString &name, const AttributeHash &attri
         // Because of this we skip attributes containing characters not belonging to any category.
         const QString data = escape( it.value() );
         const unsigned len = data.length();
-        bool nonPrint = false;
+        bool noCategory = false;
         for( unsigned i = 0; i < len; i++ )
         {
-            if( !data[i].isPrint() || ( data[i].category() == QChar::NoCategory ) )
+            if( data[i].category() == QChar::NoCategory )
             {
-                nonPrint = true;
+                noCategory = true;
                 break;
             }
         }
 
-        if( nonPrint )
+        if( noCategory )
             continue;
 
         element.setAttribute( it.key(), it.value() );
@@ -1037,7 +1035,7 @@ CollectionScanner::displayHelp()
     s_textStream << qPrintable( tr( "-s, --restart         : After a crash, restart the scanner in its last position" ) ) << endl;
     s_textStream << qPrintable( tr( "-b, --batch           : Run in batch mode" ) ) << endl;
     s_textStream << qPrintable( tr( "--idlepriority        : Run at idle priority" ) ) << endl;
-    s_textStream << qPrintable( tr( "--rpath=\"<path>\"      : In full-scan batch mode, specifies a path to prepend to entries (default is the current directory)" ) ) << endl;
+    s_textStream << qPrintable( tr( "--rpath \"<path>\"      : In full-scan batch mode, specifies a path to prepend to entries (default is the current directory)" ) ) << endl;
     s_textStream << qPrintable( tr( "--savelocation        : Internal command used by Amarok" ) ) << endl;
     s_textStream.flush();
 
